import { PublicKey } from '@metaplex-foundation/umi';
import { AssetV1, CollectionV1 } from '../generated';
/**
 * Check if the given authority is eligible to transfer the asset.
 * This does NOT check if the asset's roylaty rule sets.
 * @param {PublicKey | string} authority Pubkey
 * @param {AssetV1} asset Asset
 * @param {CollectionV1 | undefined} collection Collection
 * @returns {boolean} True if the pubkey has the authority
 */
export declare function canTransfer(authority: PublicKey | string, asset: AssetV1, collection?: CollectionV1): boolean;
/**
 * Check if the given pubkey is eligible to burn the asset.
 * @param {PublicKey | string} authority Pubkey
 * @param {AssetV1} asset Asset
 * @param {CollectionV1 | undefined} collection Collection
 * @returns {boolean} True if the pubkey has the authority
 */
export declare function canBurn(authority: PublicKey | string, asset: AssetV1, collection?: CollectionV1): boolean;
/**
 * Check if the given pubkey is eligible to update the asset.
 * @param {PublicKey | string} authority Pubkey
 * @param {AssetV1} asset Asset
 * @param {CollectionV1 | undefined} collection Collection
 * @returns {boolean} True if the pubkey has the authority
 */
export declare function canUpdate(authority: PublicKey | string, asset: AssetV1, collection?: CollectionV1): boolean;
