import { PluginHeaderV1, Plugin as BasePlugin, RegistryRecord, PluginAuthorityPair, PluginAuthority, RoyaltiesArgs, FreezeDelegateArgs, AttributesArgs, PermanentFreezeDelegateArgs, UpdateDelegateArgs } from './generated';
import { BasePluginAuthority, PluginsList } from './types';
export declare function formPluginHeaderV1(pluginRegistryOffset: bigint): Omit<PluginHeaderV1, 'publicKey' | 'header'>;
export type PluginAuthorityPairHelperArgs = CreatePluginArgs & {
    authority?: PluginAuthority;
};
export type CreatePluginArgs = {
    type: 'Royalties';
    data: RoyaltiesArgs;
} | {
    type: 'FreezeDelegate';
    data: FreezeDelegateArgs;
} | {
    type: 'BurnDelegate';
} | {
    type: 'TransferDelegate';
} | {
    type: 'UpdateDelegate';
    data?: UpdateDelegateArgs;
} | {
    type: 'Attributes';
    data: AttributesArgs;
} | {
    type: 'PermanentFreezeDelegate';
    data: PermanentFreezeDelegateArgs;
} | {
    type: 'PermanentTransferDelegate';
} | {
    type: 'PermanentBurnDelegate';
};
export declare function createPlugin(args: CreatePluginArgs): BasePlugin;
export declare function pluginAuthorityPair(args: PluginAuthorityPairHelperArgs): PluginAuthorityPair;
export declare function mapPluginFields(fields: Array<Record<string, any>>): Record<string, any>;
export declare function mapPlugin({ plugin: plug, authority, offset, }: {
    plugin: Exclude<BasePlugin, {
        __kind: 'Reserved';
    }>;
    authority: BasePluginAuthority;
    offset: bigint;
}): PluginsList;
export declare function registryRecordsToPluginsList(registryRecords: RegistryRecord[], accountData: Uint8Array): PluginsList;
export declare function pluginKeyToPluginType(pluginKey: keyof PluginsList): "Attributes" | "BurnDelegate" | "Royalties" | "FreezeDelegate" | "TransferDelegate" | "UpdateDelegate" | "PermanentFreezeDelegate" | "PermanentTransferDelegate" | "PermanentBurnDelegate";
