"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pluginKeyToPluginType = exports.registryRecordsToPluginsList = exports.mapPlugin = exports.mapPluginFields = exports.pluginAuthorityPair = exports.createPlugin = exports.formPluginHeaderV1 = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const generated_1 = require("./generated");
const authority_1 = require("./authority");
const utils_1 = require("./utils");
function formPluginHeaderV1(pluginRegistryOffset) {
    return {
        key: generated_1.Key.PluginHeaderV1,
        pluginRegistryOffset,
    };
}
exports.formPluginHeaderV1 = formPluginHeaderV1;
function createPlugin(args) {
    // TODO refactor when there are more required empty fields in plugins
    if (args.type === 'UpdateDelegate') {
        return {
            __kind: args.type,
            fields: [
                args.data || {
                    additionalDelegates: [],
                },
            ],
        };
    }
    return {
        __kind: args.type,
        fields: [args.data || {}],
    };
}
exports.createPlugin = createPlugin;
function pluginAuthorityPair(args) {
    const { type, authority, data } = args;
    // TODO refactor when there are more required empty fields in plugins
    if (type === 'UpdateDelegate') {
        return {
            plugin: {
                __kind: type,
                fields: [
                    data || {
                        additionalDelegates: [],
                    },
                ],
            },
            authority: authority ? (0, umi_1.some)(authority) : (0, umi_1.none)(),
        };
    }
    return {
        plugin: { __kind: type, fields: [data || {}] },
        authority: authority ? (0, umi_1.some)(authority) : (0, umi_1.none)(),
    };
}
exports.pluginAuthorityPair = pluginAuthorityPair;
function mapPluginFields(fields) {
    return fields.reduce((acc2, field) => ({ ...acc2, ...field }), {});
}
exports.mapPluginFields = mapPluginFields;
function mapPlugin({ plugin: plug, authority, offset, }) {
    const pluginKey = (0, utils_1.toWords)(plug.__kind)
        .toLowerCase()
        .split(' ')
        .reduce((s, c) => s + (c.charAt(0).toUpperCase() + c.slice(1)));
    return {
        [pluginKey]: {
            authority,
            offset,
            ...('fields' in plug ? mapPluginFields(plug.fields) : {}),
        },
    };
}
exports.mapPlugin = mapPlugin;
function registryRecordsToPluginsList(registryRecords, accountData) {
    return registryRecords.reduce((acc, record) => {
        const mappedAuthority = (0, authority_1.mapPluginAuthority)(record.authority);
        const deserializedPlugin = (0, generated_1.getPluginSerializer)().deserialize(accountData, Number(record.offset))[0];
        acc = {
            ...acc,
            ...mapPlugin({
                plugin: deserializedPlugin,
                authority: mappedAuthority,
                offset: record.offset,
            }),
        };
        return acc;
    }, {});
}
exports.registryRecordsToPluginsList = registryRecordsToPluginsList;
function pluginKeyToPluginType(pluginKey) {
    return (pluginKey.charAt(0).toUpperCase() +
        pluginKey.slice(1));
}
exports.pluginKeyToPluginType = pluginKeyToPluginType;
//# sourceMappingURL=plugins.js.map